@@ -5,5 +5,5 @@ pytest --cov-report term-missing --cov=amati tests
 pytest --doctest-modules amati/
 docker build -t amati -f Dockerfile . 
 cd tests/
-docker run --detach -v "$(pwd):/data" amati -d /data --consistency-check
+docker run -v "$(pwd):/data" amati -d /data --consistency-check
 cd ../
\ No newline at end of file
